#
# spec file for package thunar-shares-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define thunar_version 4.18

Name:           thunar-shares-plugin
Version:        0.5.0
Release:        1.1
URL:            https://docs.xfce.org/xfce/thunar/custom-actions
Source0:        https://archive.xfce.org/src/thunar-plugins/%{name}/0.5/%{name}-%{version}.tar.xz
Summary:        Thunar Plugin for Sharing Files Using Samba
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
BuildRequires:  gettext >= 0.19.8
BuildRequires:  meson >= 0.56.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(libxfconf-0) >= %{thunar_version}
BuildRequires:  pkgconfig(thunarx-3) >= %{thunar_version}
Requires:       samba
Requires:       thunar >= %{thunar_version}
Recommends:     %{name}-lang = %{version}
Provides:       thunar-plugin-shares = %{version}
Obsoletes:      thunar-plugin-shares < %{version}

%description
The Thunar Shares Plugin allows for quickly sharing a directory using Samba
from within Thunar without requiring root access.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

rm -rf %{buildroot}%{_libdir}/thunarx-3/thunar-shares-plugin.la

# remove unsupported locales
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%files
%{_libdir}/thunarx-3/thunar-shares-plugin.so

%files lang -f %{name}.lang

%changelog
* Tue May 27 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.5.0:
  Meson has been added as a build system in this release, and the
  associated archive has been generated by 'meson dist'. Although
  autotools has been retained for the time being and can still be used
  via 'autogen.sh', meson is now the preferred build system, and
  autotools will be removed in a future release.
  * Update README after switchover to meson
  * Add support to Meson
  * Translation Updates
* Sun Jan 19 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.4.0:
  * Fix string leaks in tsp_provider_get_menu
  * Use xfconf channel to toggle contect menu contribution
  * Context menu contribution to share folder
  * tsp-page: Fix string leak in tsp_page_set_error
  * build: Add ACLOCAL_FLAGS to ACLOCAL_AMFLAGS
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Add missing check for bind_textdomain_codeset
  * I18n: Update po/LINGUAS list
  * build: Cleanup autotools warning, remove intltool
  * tsp-page: Replace gnome-fs-share with folder-publicshare icon
  * Update documentation link
  * Translation Updates
* Sat Jan 11 2025 Maurizio Galli <maurizio.galli@suse.com>
- Package renamed from thunar-plugin-shares to thunar-shares-plugin to
  follow upstream name convention
* Wed Jan 11 2023 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 0.3.2:
  * Add basic GitLab pipeline
  * Bump GLib minimum build required to 2.26
  * configure.ac: use AC_PROG_CC_C99
  * Create README.md. Update configure.ac.in
  * Revert "configure.ac: use AC_PROG_CC_C99"
  * Translation Updates
  * Use long argument for net usershare to prevent bug (Issue #16)
* Mon Apr  6 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.3.1
  * Remove unused THUNARX_TYPE_PREFERENCES_PROVIDER, since it may cause
    crashes (iface->get_menu_items not implemented)
  * Improved spacing and layout (bxo#14657)
  * Translation Updates
* Fri Jun 15 2018 seife+obs@b1-systems.com
- update to version 0.3.0:
  * GTK3 Port
  * Thunarx-3 Port (Thunar >=1.7.0 required)
  * Translation updates
- removed obsolete patches:
  * thunar-plugin-shares-0.2.0-port-to-thunarx-2.patch
  * thunar-plugin-shares-0.2.0-fix-missing-include.patch
* Tue Apr 17 2012 gber@opensuse.org
- use upstream tarball instead of recompressed source
* Tue Mar 27 2012 gber@opensuse.org
- added source URL
* Thu Mar 22 2012 gber@opensuse.org
- corrected URL
- require samba, it does not make much sense without it
- updated build dependencies
* Thu Mar 10 2011 gber@opensuse.org
- new package (split off from thunar-plugins)
